package de.fhhannover.inform.trust.ifmapj.messages;

import java.util.Collection;
import java.util.List;

import org.w3c.dom.Document;

import de.fhhannover.inform.trust.ifmapj.identifier.Identifier;

/**
 * For PublishUpdate: If no lifetime is given, it's session.
 * 
 * For PublishDelete: If no filter string is given, it is left out --> match all
 * 
 * For Search/Subscribe: setting same parameters to NULL leaves those parameters out.
 * 
 * @author aw
 *
 */
public interface RequestFactory {
	
	public PublishRequest createPublishReq();
	
	public PublishRequest createPublishReq(PublishElement el);
	
	public PublishRequest createPublishReq(Collection<PublishElement> list);
	
	public PublishUpdate createPublishUpdate();

	public PublishUpdate createPublishUpdate(Identifier i1, Document md);

	public PublishUpdate createPublishUpdate(Identifier i1, Document md,
			MetadataLifetime lifetime);
	
	public PublishUpdate createPublishUpdate(Identifier i1, Identifier i2, Document md);

	public PublishUpdate createPublishUpdate(Identifier i1, Identifier i2,
			Document md, MetadataLifetime lifetime);

	public PublishUpdate createPublishUpdate(Identifier i1,
			Collection<Document> mdlist);

	public PublishUpdate createPublishUpdate(Identifier i1,
			Collection<Document> mdlist, MetadataLifetime lifetime);
	
	public PublishUpdate createPublishUpdate(Identifier i1, Identifier i2,
			Collection<Document> mdlist);

	public PublishUpdate createPublishUpdate(Identifier i1, Identifier i2,
			Collection<Document> mdlist, MetadataLifetime lifetime);
	
	public PublishDelete createPublishDelete();

	public PublishDelete createPublishDelete(Identifier i1);
	
	public PublishDelete createPublishDelete(Identifier i1, Identifier i2);
	
	public PublishDelete createPublishDelete(Identifier i1, String filter);
	
	public PublishDelete createPublishDelete(Identifier i1, Identifier i2, String filter);

	public PublishNotify createPublishNotify();

	public PublishNotify createPublishNotify(Identifier i1, Document md);
	
	public PublishNotify createPublishNotify(Identifier i1, Identifier i2, Document md);

	public PublishNotify createPublishNotify(Identifier i1,
			Collection<Document> mdlist);
	
	public PublishNotify createPublishNotify(Identifier i1, Identifier i2,
			Collection<Document> mdlist);

	public SearchRequest createSearchRequest(String matchLinks, Integer maxDepth,
			String terminalIdentifiers, Integer maxSize, String resultFilter,
			Identifier start);
	
	public SubscribeRequest createSubscribeReq();
	
	public SubscribeRequest createSubscribeReq(SubscribeElement el);
	
	public SubscribeRequest createSubscribeReq(List<SubscribeElement> list);
	
	public SubscribeUpdate createSubscribeUpdate();

	public SubscribeUpdate createSubscribeUpdate(String name, String matchLinks,
			Integer maxDepth, String terminalIdentifiers, Integer maxSize,
			String resultFilter, Identifier start);
	
	public SubscribeDelete createSubscribeDelete();

	public SubscribeDelete createSubscribeDelete(String name);
	
	public SearchRequest createSearchRequest();
			
}
